==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/plugins/rp/CloudDetectionAction.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp

  \brief This file defines the CreateCellLayer class
*/

// Terralib
#include "../../../qt/widgets/rp/CloudDetectionDialog.h"
#include "../../af/ApplicationController.h"
#include "../../af/BaseApplication.h"
#include "../../af/events/LayerEvents.h"
#include "CloudDetectionAction.h"

// Qt
#include <QObject>
#include <QMessageBox>
#include <QActionGroup>

// STL
#include <memory>

te::qt::plugins::rp::CloudDetectionAction::CloudDetectionAction(QMenu* menu, QMenu* popupMenu):te::qt::plugins::rp::AbstractAction(menu, popupMenu)
{
  createAction(tr("Cloud Detection...").toUtf8().data(), "cloudDetection");
  m_action->setObjectName("Processing.Raster Processing.Cloud Detection");
}

te::qt::plugins::rp::CloudDetectionAction::~CloudDetectionAction()
{
}

void te::qt::plugins::rp::CloudDetectionAction::onActionActivated(bool checked)
{
  te::map::AbstractLayerPtr layer = getCurrentLayer();

  if(!layer.get())
  {
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Cloud Detection"), tr("There is no selected raster layer."));
    return;
  }

  if(layer->getVisibility() != te::map::VISIBLE)
  {
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Cloud Detection"), tr("The layer is not checked."));
    return;
  }

  m_dlg.reset(new te::qt::widgets::CloudDetectionDialog(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

  connect(m_dlg.get(), SIGNAL(addLayer(te::map::AbstractLayerPtr)), this, SLOT(addLayer(te::map::AbstractLayerPtr)));
  connect(m_dlg.get(), SIGNAL(closeTool()), this, SLOT(closeTool()));

  te::qt::af::BaseApplication* ba = dynamic_cast<te::qt::af::BaseApplication*>(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());
  
  QActionGroup* mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance().findActionGroup("Map.ToolsGroup");
  assert(mapEditionTools);

  m_dlg->setMapDisplay(ba->getMapDisplay());
  m_dlg->setActionGroup(mapEditionTools);
  m_dlg->setLayers(getLayers());
  m_dlg->setModal(false);
  m_dlg->setUserPath(te::qt::af::AppCtrlSingleton::getInstance().getUserDataDir().toUtf8().data());
  m_dlg->show();
}

void te::qt::plugins::rp::CloudDetectionAction::addLayer(te::map::AbstractLayerPtr outputLayer)
{
  te::qt::af::evt::LayerAdded evt(outputLayer);

  emit triggered(&evt);
}

void te::qt::plugins::rp::CloudDetectionAction::addNewLayer(te::map::AbstractLayerPtr layer)
{
  te::qt::af::evt::LayerAdded evt(layer.get());

  emit triggered(&evt);
}

std::list<te::map::AbstractLayerPtr> te::qt::plugins::rp::CloudDetectionAction::getLayers()
{
  te::qt::af::evt::GetAvailableLayers e;
  te::qt::af::evt::GetLayerSelected ed;

  emit triggered(&e);
  emit triggered(&ed);

  std::list<te::map::AbstractLayerPtr> layers = e.m_layers;
  te::map::AbstractLayerPtr selectedlayer = ed.m_layer;

  if (!selectedlayer)
    return layers;

  std::list<te::map::AbstractLayerPtr> result;

  result.push_back(selectedlayer);

  for (std::list<te::map::AbstractLayerPtr>::iterator it = layers.begin(); it != layers.end(); ++it)
  {
    if ((*it)->getId() != selectedlayer->getId())
      result.push_back(*it);
  }

  return result;
}

void te::qt::plugins::rp::CloudDetectionAction::closeTool()
{
  m_dlg.reset(0);
}

==> download.php?FileName=terralib-5.4.0.zip: src/terralib/qt/plugins/rp/CloudDetectionAction.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp

  \brief This file defines the CreateCellLayer class
*/

// Terralib
#include "../../../qt/widgets/rp/CloudDetectionDialog.h"
#include "../../af/ApplicationController.h"
#include "../../af/BaseApplication.h"
#include "../../af/events/LayerEvents.h"
#include "CloudDetectionAction.h"

// Qt
#include <QObject>
#include <QMessageBox>
#include <QActionGroup>

// STL
#include <memory>

te::qt::plugins::rp::CloudDetectionAction::CloudDetectionAction(QMenu* menu, QMenu* popupMenu):te::qt::plugins::rp::AbstractAction(menu, popupMenu)
{
  createAction(tr("Cloud Detection...").toUtf8().data(), "cloudDetection");
  m_action->setObjectName("Processing.Raster Processing.Cloud Detection");
}

te::qt::plugins::rp::CloudDetectionAction::~CloudDetectionAction() = default;

void te::qt::plugins::rp::CloudDetectionAction::onActionActivated(
    bool /*checked*/)
{
  m_dlg.reset(new te::qt::widgets::CloudDetectionDialog(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

  connect(m_dlg.get(), SIGNAL(addLayer(te::map::AbstractLayerPtr)), this, SLOT(addLayer(te::map::AbstractLayerPtr)));
  connect(m_dlg.get(), SIGNAL(closeTool()), this, SLOT(closeTool()));

  te::qt::af::BaseApplication* ba = dynamic_cast<te::qt::af::BaseApplication*>(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());
  
  QActionGroup* mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance().findActionGroup("Map.ToolsGroup");
  assert(mapEditionTools);

  std::list<te::map::AbstractLayerPtr> layersList = getLayers();

  m_dlg->setMapDisplay(ba->getMapDisplay());
  m_dlg->setActionGroup(mapEditionTools);
  m_dlg->setModal(false);
  m_dlg->setLayers(layersList);
  m_dlg->setUserPath(te::qt::af::AppCtrlSingleton::getInstance().getUserDataDir().toUtf8().data());
  m_dlg->show();
}

void te::qt::plugins::rp::CloudDetectionAction::addLayer(te::map::AbstractLayerPtr outputLayer)
{
  //add new layer
  addNewLayer(outputLayer);
}

void te::qt::plugins::rp::CloudDetectionAction::closeTool()
{
  m_dlg.reset(nullptr);
}
